pub struct InspectUrlIndexRequest {
pub inspection_url: Option<String>,
pub language_code: Option<String>,
pub site_url: Option<String>,
}Expand description
Index inspection request.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- index inspect url inspection (request)
Fields
inspection_url: Option<String>Required. URL to inspect. Must be under the property specified in “site_url”.
language_code: Option<String>Optional. An IETF BCP-47 language code representing the requested language for translated issue messages, e.g. “en-US”, “or “de-CH”. Default value is “en-US”.
site_url: Option<String>Required. The URL of the property as defined in Search Console. Examples: http://www.example.com/ for a URL-prefix property, or sc-domain:example.com for a Domain property.