pub struct RichResultsIssue {
pub issue_message: Option<String>,
pub severity: Option<String>,
}Expand description
Severity and status of a single issue affecting a single rich result instance on a page.
This type is not used in any activity, and only used as part of another schema.
Fields
issue_message: Option<String>Rich Results issue type.
severity: Option<String>Severity of this issue: WARNING, or ERROR. Items with an issue of status ERROR cannot appear with rich result features in Google Search results.