[][src]Struct google_searchconsole1::RunMobileFriendlyTestRequest

pub struct RunMobileFriendlyTestRequest {
    pub url: Option<String>,
    pub request_screenshot: Option<bool>,
}

Mobile-friendly test request.

Activities

This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).

Fields

url: Option<String>

URL for inspection.

request_screenshot: Option<bool>

Whether or not screenshot is requested. Default is false.