A filter test to be applied to each row in the data set, where a match can return the row. Filters are string comparisons, and values and dimension names are not case-sensitive. Individual filters are either AND’ed or OR’ed within their parent filter group, according to the group’s group type. You do not need to group by a specified dimension to filter against it.
A set of dimension value filters to test against each row. Only rows that pass all filter groups will be returned. All results within a filter group are either AND’ed or OR’ed together, depending on the group type selected. All filter groups are AND’ed together.
Results of index status inspection for either the live page or the version in Google’s index, depending on whether you requested a live inspection or not. For more information, see the Index coverage report documentation.
An object that may be returned with your query results, providing context about the state of the data. When you request recent data (using all or hourly_all for dataState), some of the rows returned may represent data that is incomplete, which means that the data is still being collected and processed. This metadata object helps you identify exactly when this starts and ends. All dates and times provided in this object are in the America/Los_Angeles time zone. The specific field returned within this object depends on how you’ve grouped your data in the request. See details in inner fields.
A list of rows, one per result, grouped by key. Metrics in each row are aggregated for all data grouped by that key either by page or property, as specified by the aggregation type parameter.
Query your data with filters and parameters that you define. Returns zero or more rows grouped by the row keys that you define. You must define a date range of one or more days. When date is one of the group by values, any days without data are omitted from the result list. If you need to know which days have data, issue a broad date range query grouped by date for any metric, and see which day rows are returned.
Deletes a sitemap from the Sitemaps report. Does not stop Google from crawling this sitemap or the URLs that were previously crawled in the deleted sitemap.