pub struct AmpInspectionResult {
pub amp_index_status_verdict: Option<String>,
pub amp_url: Option<String>,
pub indexing_state: Option<String>,
pub issues: Option<Vec<AmpIssue>>,
pub last_crawl_time: Option<DateTime<Utc>>,
pub page_fetch_state: Option<String>,
pub robots_txt_state: Option<String>,
pub verdict: Option<String>,
}Expand description
AMP inspection result of the live page or the current information from Google’s index, depending on whether you requested a live inspection or not.
This type is not used in any activity, and only used as part of another schema.
Fields
amp_index_status_verdict: Option<String>Index status of the AMP URL.
amp_url: Option<String>URL of the AMP that was inspected. If the submitted URL is a desktop page that refers to an AMP version, the AMP version will be inspected.
indexing_state: Option<String>Whether or not the page blocks indexing through a noindex rule.
issues: Option<Vec<AmpIssue>>A list of zero or more AMP issues found for the inspected URL.
last_crawl_time: Option<DateTime<Utc>>Last time this AMP version was crawled by Google. Absent if the URL was never crawled successfully.
page_fetch_state: Option<String>Whether or not Google could fetch the AMP.
robots_txt_state: Option<String>Whether or not the page is blocked to Google by a robots.txt rule.
verdict: Option<String>The status of the most severe error on the page. If a page has both warnings and errors, the page status is error. Error status means the page cannot be shown in Search results.